==> keycloak-model-map-20.0.3-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityFieldDelegate.java <==
package org.keycloak.models.map.singleUseObject;
public class MapSingleUseObjectEntityFieldDelegate extends org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity.AbstractSingleUseObjectEntity implements org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> entityFieldDelegate;
    public MapSingleUseObjectEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getObjectKey() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY);
    }
    @SuppressWarnings("unchecked") @Override public void setObjectKey(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0, p1);
    }
}

==> keycloak-model-map-21.0.0-sources.jar: org/keycloak/models/map/singleUseObject/MapSingleUseObjectEntityFieldDelegate.java <==
package org.keycloak.models.map.singleUseObject;
@javax.annotation.processing.Generated("org.keycloak.models.map.processor.GenerateEntityImplementationsProcessor")
public class MapSingleUseObjectEntityFieldDelegate extends org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity.AbstractSingleUseObjectEntity implements org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity, org.keycloak.models.map.common.delegate.HasEntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> {
    private final org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> entityFieldDelegate;
    public MapSingleUseObjectEntityFieldDelegate(org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> entityFieldDelegate) {
        this.entityFieldDelegate = entityFieldDelegate;
    }
    public org.keycloak.models.map.common.delegate.EntityFieldDelegate<org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntity> getEntityFieldDelegate() {
        return this.entityFieldDelegate;
    }
    @Override public boolean isUpdated() {
        return entityFieldDelegate.isUpdated();
    }
    @Override public void clearUpdatedFlag() {
        entityFieldDelegate.clearUpdatedFlag();
    }
    @SuppressWarnings("unchecked") @Override public String getId() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID);
    }
    @SuppressWarnings("unchecked") @Override public void setId(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.ID, p0);
    }
    @SuppressWarnings("unchecked") @Override public Long getExpiration() {
        return (Long) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION);
    }
    @SuppressWarnings("unchecked") @Override public void setExpiration(Long p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.EXPIRATION, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getObjectKey() {
        return (String) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY);
    }
    @SuppressWarnings("unchecked") @Override public void setObjectKey(String p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.OBJECT_KEY, p0);
    }
    @SuppressWarnings("unchecked") @Override public java.util.Map<String,String> getNotes() {
        return (java.util.Map<String,String>) entityFieldDelegate.get(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES);
    }
    @SuppressWarnings("unchecked") @Override public void setNotes(java.util.Map<String,String> p0) {
        entityFieldDelegate.set(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public String getNote(String p0) {
        return (String) entityFieldDelegate.mapGet(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0);
    }
    @SuppressWarnings("unchecked") @Override public void setNote(String p0, String p1) {
        entityFieldDelegate.mapPut(org.keycloak.models.map.singleUseObject.MapSingleUseObjectEntityFields.NOTES, p0, p1);
    }
}
